<img src="https://psiturk.org/static/images/psiturk_logo_README.png">

[![Build Status](https://travis-ci.org/NYUCCL/psiTurk.png?branch=master)](https://travis-ci.org/NYUCCL/psiTurk)
[![Coverage Status](http://coveralls.io/repos/NYUCCL/psiTurk/badge.png?branch=master)](http://coveralls.io/r/NYUCCL/psiTurk?branch=master)
[![Code Health](https://landscape.io/github/NYUCCL/psiTurk/master/landscape.png)](https://landscape.io/github/NYUCCL/psiTurk/master)
[![License](http://img.shields.io/badge/license-MIT-red.svg)](http://en.wikipedia.org/wiki/MIT_License)

Please visit [psiturk.org](https://psiturk.org) for more information.

[Psiturk Google Group](https://groups.google.com/forum/#!forum/psiturk)



# Developing

Check out a clone of this repo, and install it into your local environment for testing
(consider installing into a virtualenv):

```
git clone git@github.com:NYUCCL/psiTurk.git
git install -e psiTurk
```

A test suite can be run using `pytest` from within the base directory of psiturk.


# Citing 

You are welcome to use this code for personal or academic uses. If you fork,
or use this in an academic paper please cite as follows:

McDonnell, J.V., Martin, J.B., Markant, D.B., Coenen, A., Rich, A.S., and Gureckis, T.M. 
(2012). psiTurk (Version 1.02) [Software]. New York, NY: New York University. 
Available from https://github.com/NYUCCL/psiTurk

